<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>U2::BallPlugin</name>
    <message>
        <location filename="../src/BallPlugin.cpp" line="16"/>
        <source>BALL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/BallPlugin.cpp" line="16"/>
        <source>A port of BALL framework for molecular surface calculation</source>
        <translation></translation>
    </message>
</context>
</TS>
